@@ -20,7 +20,7 @@ from geoip2.mixins import SimpleEquality
 
 
 class Country(SimpleEquality):
-    """Model for the GeoIP2 Precision: Country and the GeoIP2 Country database.
+    """Model for the Country web service and Country database.
 
     This class provides the following attributes:
 
@@ -105,7 +105,7 @@ class Country(SimpleEquality):
 
 
 class City(Country):
-    """Model for the GeoIP2 Precision: City and the GeoIP2 City database.
+    """Model for the City Plus web service and the City database.
 
     .. attribute:: city
 
@@ -193,7 +193,7 @@ class City(Country):
 
 
 class Insights(City):
-    """Model for the GeoIP2 Precision: Insights web service endpoint.
+    """Model for the GeoIP2 Insights web service.
 
     .. attribute:: city
 
@@ -325,11 +325,13 @@ class SimpleModel(SimpleEquality, metaclass=ABCMeta):
 
     raw: Dict[str, Union[bool, str, int]]
     ip_address: str
+    _network: Optional[Union[ipaddress.IPv4Network, ipaddress.IPv6Network]]
+    _prefix_len: int
 
     def __init__(self, raw: Dict[str, Union[bool, str, int]]) -> None:
         self.raw = raw
         self._network = None
-        self._prefix_len = raw.get("prefix_len")
+        self._prefix_len = cast(int, raw.get("prefix_len"))
         self.ip_address = cast(str, raw.get("ip_address"))
 
     def __repr__(self) -> str:
@@ -340,7 +342,7 @@ class SimpleModel(SimpleEquality, metaclass=ABCMeta):
         """The network for the record"""
         # This code is duplicated for performance reasons
         network = self._network
-        if isinstance(network, (ipaddress.IPv4Network, ipaddress.IPv6Network)):
+        if network is not None:
             return network
 
         ip_address = self.ip_address
@@ -404,7 +406,7 @@ class AnonymousIP(SimpleModel):
 
       The IP address used in the lookup.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: network
 
@@ -448,13 +450,13 @@ class ASN(SimpleModel):
       The organization associated with the registered autonomous system number
       for the IP address.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: ip_address
 
       The IP address used in the lookup.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: network
 
@@ -495,13 +497,13 @@ class ConnectionType(SimpleModel):
 
       Additional values may be added in the future.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: ip_address
 
       The IP address used in the lookup.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: network
 
@@ -528,13 +530,13 @@ class Domain(SimpleModel):
 
       The domain associated with the IP address.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: ip_address
 
       The IP address used in the lookup.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: network
 
@@ -569,25 +571,41 @@ class ISP(ASN):
       The organization associated with the registered autonomous system number
       for the IP address.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: isp
 
       The name of the ISP associated with the IP address.
 
-      :type: unicode
+      :type: str
+
+    .. attribute: mobile_country_code
+
+      The `mobile country code (MCC)
+      <https://en.wikipedia.org/wiki/Mobile_country_code>`_ associated with the
+      IP address and ISP.
+
+      :type: str
+
+    .. attribute: mobile_network_code
+
+      The `mobile network code (MNC)
+      <https://en.wikipedia.org/wiki/Mobile_country_code>`_ associated with the
+      IP address and ISP.
+
+      :type: str
 
     .. attribute:: organization
 
       The name of the organization associated with the IP address.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: ip_address
 
       The IP address used in the lookup.
 
-      :type: unicode
+      :type: str
 
     .. attribute:: network
 
@@ -599,10 +617,14 @@ class ISP(ASN):
     """
 
     isp: Optional[str]
+    mobile_country_code: Optional[str]
+    mobile_network_code: Optional[str]
     organization: Optional[str]
 
     # pylint:disable=too-many-arguments
     def __init__(self, raw: Dict[str, Union[str, int]]) -> None:
         super().__init__(raw)
         self.isp = cast(Optional[str], raw.get("isp"))
+        self.mobile_country_code = cast(Optional[str], raw.get("mobile_country_code"))
+        self.mobile_network_code = cast(Optional[str], raw.get("mobile_network_code"))
         self.organization = cast(Optional[str], raw.get("organization"))
